Module git

Module git 

Functions

git_checkout_branch_command
Build a git checkout -B command for branch.
git_command
Build a git command scoped to root with conflicting git env removed.
git_command_output
Run git with the supplied args and capture the raw process output.
git_commit_paths_command
Build a git commit command for the supplied monochange commit message.
git_current_branch
Return the current branch name for the repository at root.
git_error_detail
Prefer stderr over stdout when rendering a git failure detail string.
git_head_commit
Return the full HEAD commit SHA for the repository at root.
git_push_branch_command
Build a force-with-lease push command for branch.
git_reports_nothing_to_commit
Detect the standard nothing to commit git response.
git_stage_paths_command
Build a git add -A -- ... command for the provided tracked paths.
git_stderr_trimmed
Return stderr as trimmed UTF-8 lossily decoded text.
git_stdout_trimmed
Return stdout as trimmed UTF-8 lossily decoded text.
run_command
Run a prepared command and convert process failures into MonochangeError.
run_commit_command_allow_nothing_to_commit
Run a commit command and treat nothing to commit as success.