Functions
- git_
checkout_ branch_ command - Build a
git checkout -Bcommand forbranch. - git_
command - Build a
gitcommand scoped torootwith conflicting git env removed. - git_
command_ output - Run
gitwith the supplied args and capture the raw process output. - git_
commit_ paths_ command - Build a
git commitcommand for the supplied monochange commit message. - git_
current_ branch - Return the current branch name for the repository at
root. - git_
error_ detail - Prefer stderr over stdout when rendering a git failure detail string.
- git_
head_ commit - Return the full HEAD commit SHA for the repository at
root. - git_
push_ branch_ command - Build a force-with-lease push command for
branch. - git_
reports_ nothing_ to_ commit - Detect the standard
nothing to commitgit response. - git_
stage_ paths_ command - Build a
git add -A -- ...command for the provided tracked paths. - git_
stderr_ trimmed - Return stderr as trimmed UTF-8 lossily decoded text.
- git_
stdout_ trimmed - Return stdout as trimmed UTF-8 lossily decoded text.
- run_
command - Run a prepared command and convert process failures into
MonochangeError. - run_
commit_ command_ allow_ nothing_ to_ commit - Run a commit command and treat
nothing to commitas success.